# Thinc Webservice
Adds i18n and delta support for models to [django-restframework](http://www.django-rest-framework.org/)

[![Build Status](https://api.travis-ci.org/webair/thinc.django-webservice.svg)](https://travis-ci.org/webair/thinc.django-webservice)
[![Coverage Status](https://coveralls.io/repos/webair/thinc.django-webservice/badge.svg?branch=develop)](https://coveralls.io/r/webair/thinc.django-webservice?branch=develop)

## Requirements
- Django (1.8 or higher)
- djangorestframework (3.1 or higher)
- pytz (2014.10 or higher)
- django-grappelli (2.6.0 or higher)